%define anolis_release 1
Name:          perl-Net-DNS
Version:       1.36
Release:       %{anolis_release}%{?dist}
Summary:       DNS resolver modules for Perl
# Other files:          MIT
# demo/mresolv:         GPL+ or Artistic
## Not in a binary package
# contrib/find_zonecut: GPL+ or Artistic
# contrib/check_soa:    GPL+ or Artistic
License:       (GPL+ or Artistic) and MIT
URL:           https://www.net-dns.org
Source0:       https://www.net-dns.org/download/Net-DNS-%{version}.tar.gz

BuildArch:     noarch

BuildRequires: coreutils
BuildRequires: findutils
BuildRequires: make

BuildRequires: perl-generators
BuildRequires: perl-interpreter
BuildRequires: perl(Config)
BuildRequires: perl(ExtUtils::MakeMaker) >= 6.76
BuildRequires: perl(Getopt::Long)
# IO::Socket::IP or IO::Socket::INET
BuildRequires: perl(IO::Socket::IP) >= 0.38
# Runtime
BuildRequires: perl(base)
BuildRequires: perl(Carp)
# Config not used
BuildRequires: perl(constant)
BuildRequires: perl(Data::Dumper)
# Digest::GOST is optional and intentionally unavailable
# Digest::GOST::CryptoPro is optional and intentionally unavailable
BuildRequires: perl(Digest::HMAC) >= 1.03
BuildRequires: perl(Digest::MD5) >= 2.13
BuildRequires: perl(Digest::SHA) >= 5.23
BuildRequires: perl(Encode)
BuildRequires: perl(Exporter)
BuildRequires: perl(File::Spec)
BuildRequires: perl(FileHandle)
BuildRequires: perl(integer)
BuildRequires: perl(IO::File)
# IO::Select is not used
# Prefer IO::Socket::IP over IO::Socket::INET for IPv6 support
BuildRequires: perl(MIME::Base64) >= 2.13
# Prefer Net::LibIDN2 over Net::LibIDN, both are optional
BuildRequires: perl(Net::LibIDN2) >= 1
BuildRequires: perl(overload)
# PerlIO is optional
# Scalar::Util is optional
BuildRequires: perl(Socket)
BuildRequires: perl(strict)
BuildRequires: perl(Time::Local)
BuildRequires: perl(warnings)
# Win32::IPHelper is not needed
# Win32::TieRegistry is not needed
# Tests only
BuildRequires: perl(File::Find) >= 1.05
BuildRequires: perl(Test::Builder)
BuildRequires: perl(Test::More)
# Optional tests:
BuildRequires: perl(Test::Pod) >= 1.45
Suggests:      perl(Config)
Requires:      perl(Data::Dumper)
# Digest::GOST not available
Requires:      perl(Digest::HMAC) >= 1.03
Requires:      perl(Digest::MD5) >= 2.13
Requires:      perl(Digest::SHA) >= 5.23
Requires:      perl(Encode)
# Prefer IO::Socket::IP over IO::Socket::INET for IPv6 support
Recommends:    perl(IO::Socket::IP) >= 0.38
Requires:      perl(MIME::Base64) >= 2.13
# Net::DNS::Extlang not available
Suggests:      perl(Net::DNS::SEC::DSA)
# Net::DNS::SEC::ECCGOST not available
Suggests:      perl(Net::DNS::SEC::ECDSA)
Suggests:      perl(Net::DNS::SEC::EdDSA)
Suggests:      perl(Net::DNS::SEC::Private)
Suggests:      perl(Net::DNS::SEC::RSA)
# Prefer Net::LibIDN2 over Net::LibIDN, both are optional
Suggests:      perl(Net::LibIDN2) >= 1
Suggests:      perl(Scalar::Util) >= 1.25

%{?perl_default_filter}

# Do not export under-specified dependencies
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(Digest::HMAC\\)$
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(Digest::MD5\\)$
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(Digest::SHA\\)$
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(MIME::Base64\\)$
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(CONFIG\\)$
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(OS_CONF\\)$
# Do not export under-specified provides
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^perl\\((Net::DNS::Text)\\)$
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^perl\\((Net::DNS::RR::OPT)\\)$
# Remove private modules
%global __provides_exclude %{?__provides_exclude:%__provides_exclude|}^perl\\(NonFatal\\)$

%description
Net::DNS is a collection of Perl modules that act as a Domain Name System
(DNS) resolver. It allows the programmer to perform DNS queries that are
beyond the capabilities of gethostbyname and gethostbyaddr.

The programmer should be somewhat familiar with the format of a DNS packet and
its various sections. See RFC 1035 or DNS and BIND (Albitz & Liu) for details.

%package Nameserver
Summary:        DNS server for Perl
License:        MIT
Recommends:     perl(IO::Socket::IP) >= 0.32

%description Nameserver
Instances of the "Net::DNS::Nameserver" class represent DNS server objects.

%package tests
Summary:        Tests for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       perl-Test-Harness

%description tests
Tests from %{name}. Execute them
with "%{_libexecdir}/%{name}/test".

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%setup -q -n Net-DNS-%{version} 
chmod -x demo/*
perl -MConfig -i -pe 's{^#!/usr/local/bin/perl}{$Config{startperl}}' demo/*
# Remove author tests
for F in \
    t/00-install.t \
    t/00-pod.t \
    ; do
    rm "$F"
    perl -i -ne 'print $_ unless m{\A\Q'"$F"'\E}' MANIFEST
done
# Help generators to recognize Perl scripts
for F in t/*.t; do
    chmod +x "$F"
done

%build
export PERL_MM_USE_DEFAULT=yes
perl Makefile.PL INSTALLDIRS=vendor NO_PACKLIST=1 NO_PERLLOCAL=1 --no-online-tests
%{make_build}

%install
%{make_install}
find %{buildroot} -type f -name '*.bs' -a -size 0 -delete
%{_fixperms} %{buildroot}/*
# Install tests
mkdir -p %{buildroot}%{_libexecdir}/%{name}
cp -a t %{buildroot}%{_libexecdir}/%{name}
cat > %{buildroot}%{_libexecdir}/%{name}/test << 'EOF'
#!/bin/sh
cd %{_libexecdir}/%{name} && exec prove -I . -j "$(getconf _NPROCESSORS_ONLN)"
EOF
chmod +x %{buildroot}%{_libexecdir}/%{name}/test

%check
make test

%files
%doc demo
%{perl_vendorlib}/Net/
%exclude %{perl_vendorlib}/Net/DNS/Resolver/cygwin.pm
%exclude %{perl_vendorlib}/Net/DNS/Resolver/MSWin32.pm
%{_mandir}/man3/Net::DNS*.3*
%exclude %{_mandir}/man3/Net::DNS::Resolver::cygwin.3*
%exclude %{_mandir}/man3/Net::DNS::Resolver::MSWin32.3*
# perl-Net-DNS-Nameserver
%exclude %{perl_vendorlib}/Net/DNS/Nameserver.pm
%exclude %{_mandir}/man3/Net::DNS::Nameserver*

%files doc
%doc README Changes

%files Nameserver
%{perl_vendorlib}/Net/DNS/Nameserver.pm
%{_mandir}/man3/Net::DNS::Nameserver*

%files tests
%{_libexecdir}/%{name}

%changelog
* Fri Feb 3 2023 Funda Wang <fundawang@yeah.net - 1.36-1
- Import package for anolis 23
